ZoomDialog class
Properties
-
backgroundColor
→ Color?
-
Background color
final
-
barrierColor
→ Color?
-
finalinherited
-
blur
→ double?
-
Creates an background filter that applies a Gaussian blur.
Default = 0
finalinherited
-
child
→ Widget
-
The (optional) content of the dialog is displayed in the center of the dialog in a lighter font.
final
-
dialog
→ Widget?
-
Widget of dialog, you can use d_dialog, Dialog, AlertDialog or Custom your own Dialog
finalinherited
-
dismissable
→ bool?
-
Because blur dialog cover the barrier, you have to declare here
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
initZoomScale
→ double
-
Initialize zoom scale on dialog show
final
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onDismiss
→ void Function()?
-
Action before dialog dismissed
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
zoomScale
→ double
-
Maximum zoom scale
final
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
show<T>(BuildContext context, {DialogTransitionType? transitionType, bool? dismissable, Duration? transitionDuration})
→ Future<T?>
-
Show dialog directly
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited